internal

package
v0.0.0-...-1b9858f Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 10, 2025 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func HostID

func HostID() (string, error)

HostID returns the unique host ID provided by the OS.

func Or

func Or[T any](cond bool, y, n T) T

Or returns y if cond is true, n otherwise.

func ToBytes

func ToBytes(s string) []byte

ToBytes converts string to byte slice without a memory allocation.

For more details, see https://github.com/golang/go/issues/53003#issuecomment-1140276077.

func ToString

func ToString(bs []byte) string

ToString converts byte slice to string without a memory allocation.

For more details, see https://github.com/golang/go/issues/53003#issuecomment-1140276077.

Types

This section is empty.

Jump to